@@ -51,6 +51,11 @@ class GetInstanceInspectionsRequest(RpcRequest):
 
 	def set_InstanceArea(self, InstanceArea):  # String
 		self.add_query_param('InstanceArea', InstanceArea)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_Engine(self): # String
 		return self.get_query_params().get('Engine')
 
